*******************
***** Table 1 *****
*******************
*Detailed Results for U.S. Senate Elections
clear
set more off
use "data.dta"
keep if setting == "senate"
*Top Panel, Column 1
xi:areg voteshare incumbency i.setting, a(year) cluster(setting_unit)
scalar estimate1 = _b[incumbency]
*Top Panel, Column 2
xi:areg voteshare incumbency i.year, a(setting_unit_decade) cluster(setting_unit)
scalar estimate2 = _b[incumbency]
*Top Panel, Column 3
xi:reg incumbency treatment rv* i.setting i.year if absrv < .5, cluster(setting_unit)
test treatment = 0
*Top Panel, Column 4
xi:ivregress 2sls voteshare (incumbency = treatment) rv* i.setting i.year if absrv < .5, cluster(setting_unit)
scalar estimate3 = _b[incumbency]
*Party Match
disp round((estimate1 - estimate2)*1000)/1000
*Characteristic Selection
disp round((estimate2 - estimate3)*1000)/1000
*Officeholder Benefit
disp round(estimate3*1000)/1000
*For the confidence intervals associated with PM, CS, and OB, see the code for Table 2.


*******************
***** Table 2 *****
*******************
*Results across Electoral Settings
clear
set matsize 10000
set more off
set seed 60637
use "data.dta"
g senate = setting == "senate"
g house = setting == "house"
g governor = setting == "gov"
g statewidehigh = setting == "attygenl" | setting == "secstate" | setting == "ltgov"
g statewidelow = setting == "agric" | setting == "auditor" | setting == "clerk" ///
| setting == "comptroll" | setting == "education" | setting == "finance" | setting == "inspector" ///
| setting == "insurance" | setting == "labor" | setting == "lands" | setting == "mines" ///
| setting == "printer" | setting == "reporter" | setting == "surveyor" | setting == "treasurer"
g stleg = setting == "stleg"
g mayor = setting == "mayors"
g pooled = 1
foreach i in senate house governor statewidehigh statewidelow stleg mayor pooled {
quietly{
xi:areg voteshare incumbency i.setting if `i' == 1, a(year) cluster(setting_unit)
scalar estimate1 = _b[incumbency]
xi:areg voteshare incumbency i.year if `i' == 1, a(setting_unit_decade) cluster(setting_unit)
scalar estimate2 = _b[incumbency]
xi:ivregress 2sls voteshare (incumbency = treatment) rv* i.setting i.year if absrv < .5 & `i' == 1, cluster(setting_unit)
scalar estimate3 = _b[incumbency]
}
scalar `i'_pm = estimate1 - estimate2
scalar `i'_cs = estimate2 - estimate3
scalar `i'_ob = estimate3
scalar `i'_cspmratio = (estimate2 - estimate3)/(estimate1 - estimate2) 
scalar `i'_obprop = estimate3/estimate1
disp "`i'"
}
*Point Estimates
foreach i in senate house governor statewidehigh statewidelow stleg mayor pooled {
foreach j in pm cs ob cspmratio obprop {
disp "`i' `j'"
disp round((`i'_`j')*1000)/1000
}
}
*Bootstrap for Confidence Intervals
/*
Warning: This takes approximately 11 hours on my desktop computer. To save time, 
users can reduce the number of runs below (e.g., change "local runs = 1000" to
"local runs = "200"). This will reduce the precision with which the confidence 
intervals are estimated, and they won't perfectly match the numbers in the 
table. If you change the number, be sure to pick a multiple of 40, so that you
will have exactly 5% of the bootstrapped samples outside your confidence interavals.  
*/
local runs = 1000
scalar lower = floor(`runs'*.025) + 1
scalar upper = floor(`runs'*.975)
foreach i in senate house governor statewidehigh statewidelow stleg mayor pooled {
matrix `i' = J(`runs', 3, .)
}
forvalues i = 1/`runs' {
quietly{
preserve
bsample, cluster(setting_unit)
	foreach j in senate house governor statewidehigh statewidelow stleg mayor pooled {
	xi:areg voteshare incumbency i.setting if `j' == 1, a(year) cluster(setting_unit)
	scalar estimate1 = _b[incumbency]
	xi:areg voteshare incumbency i.year if `j' == 1, a(setting_unit_decade) cluster(setting_unit)
	scalar estimate2 = _b[incumbency]
	xi:ivregress 2sls voteshare (incumbency = treatment) rv* i.setting i.year if absrv < .5 & `j' == 1, cluster(setting_unit)
	scalar estimate3 = _b[incumbency]
	matrix `j'[`i',1] = estimate1 - estimate2 
	matrix `j'[`i',2] = estimate2 - estimate3
	matrix `j'[`i',3] = estimate3
	}
restore
}
if round(`i'/100) == (`i'/100) {
	disp `i'
	disp "$S_TIME"
	}
}
postfile Results pm pm_lower pm_upper cs cs_lower cs_upper ob ob_lower ob_upper cspmratio cspmratio_lower cspmratio_upper obprop obprop_lower obprop_upper using "Table_Results.dta", replace
foreach i in senate house governor statewidehigh statewidelow stleg mayor pooled {
quietly {
svmat `i'
g `i'4 = `i'2/`i'1
g `i'5 = `i'3/(`i'1 + `i'2 + `i'3)
sort `i'1
sum `i'1 if _n == lower
scalar `i'_pm_lower = r(mean)
sum `i'1 if _n == upper
scalar `i'_pm_upper = r(mean)
sort `i'2
sum `i'2 if _n == lower
scalar `i'_cs_lower = r(mean)
sum `i'2 if _n == upper
scalar `i'_cs_upper = r(mean)
sort `i'3
sum `i'3 if _n == lower
scalar `i'_ob_lower = r(mean)
sum `i'3 if _n == upper
scalar `i'_ob_upper = r(mean)
sort `i'4
sum `i'4 if _n == lower
scalar `i'_cspmratio_lower = r(mean)
sum `i'4 if _n == upper
scalar `i'_cspmratio_upper = r(mean)
sort `i'5
sum `i'5 if _n == lower
scalar `i'_obprop_lower = r(mean)
sum `i'5 if _n == upper
scalar `i'_obprop_upper = r(mean)
post Results (`i'_pm) (`i'_pm_lower) (`i'_pm_upper) (`i'_cs) (`i'_cs_lower) (`i'_cs_upper) (`i'_ob) (`i'_ob_lower) (`i'_ob_upper) (`i'_cspmratio) (`i'_cspmratio_lower) (`i'_cspmratio_upper) (`i'_obprop) (`i'_obprop_lower) (`i'_obprop_upper)
}
}
postclose Results
clear
set more off
use "Table_Results.dta"
g setting = "Senate" if _n == 1
replace setting = "House" if _n == 2
replace setting = "Governors" if _n == 3
replace setting = "Statewide High" if _n == 4
replace setting = "Statewide Low" if _n == 5
replace setting = "State Legislatures" if _n == 6
replace setting = "Mayors" if _n == 7
replace setting = "Pooled" if _n == 8
g order = _n
order setting
foreach i of varlist pm-obprop_upper {
tostring `i', replace format(%5.3f) force
replace `i' = subinstr(`i', "0.", ".", .)
replace `i' = subinstr(`i', "-.000", ".000", .)
replace `i' = trim(`i')
}
foreach i in pm cs ob cspmratio obprop {
rename `i' `i'0
g `i'1 = "[" + `i'_lower + "," + `i'_upper + "]"
}
keep setting order *0 *1
reshape long pm cs ob cspmratio obprop, i(order) j(uncertainty)
sort order uncertainty
order order uncertainty
save "Table_Results_Cleaned.dta", replace
browse


*******************
***** Table 3 *****
*******************
*Variation across Public Financing and Term Limits
clear
set matsize 10000
set more off
set seed 60637
use "data.dta"
keep if setting == "stleg"
g clean = public_funding == 1
g noclean = public_funding == 0
g termlimits = term_limit == 1
g notermlimits = term_limit == 0
drop public_funding term_limit
foreach i in clean noclean termlimits notermlimits {
quietly{
xi:areg voteshare incumbency i.setting if `i' == 1, a(year) cluster(setting_unit)
scalar estimate1 = _b[incumbency]
xi:areg voteshare incumbency i.year if `i' == 1, a(setting_unit_decade) cluster(setting_unit)
scalar estimate2 = _b[incumbency]
xi:ivregress 2sls voteshare (incumbency = treatment) rv* i.setting i.year if absrv < .5 & `i' == 1, cluster(setting_unit)
scalar estimate3 = _b[incumbency]
scalar `i'_pm = estimate1 - estimate2
scalar `i'_cs = estimate2 - estimate3
scalar `i'_ob = estimate3
}
}
foreach i in clean termlimits {
foreach j in pm cs ob {
scalar `i'diff_`j' = `i'_`j' - no`i'_`j'
}
}
*Point Estimates
foreach i in clean noclean cleandiff termlimits notermlimits termlimitsdiff {
foreach j in pm cs ob {
disp "`i'_`j'"
disp round(`i'_`j'*1000)/1000
}
}
*Bootstrap for Confidence Intervals
/*
Warning: This takes approximately 2 hours on my desktop computer. To save time, 
users can reduce the number of runs below (e.g., change "local runs = 1000" to
"local runs = "200"). This will reduce the precision with which the confidence 
intervals are estimated, and they won't perfectly match the numbers in the 
table. If you change the number, be sure to pick a multiple of 40, so that you
will have exactly 5% of the bootstrapped samples outside your confidence interavals.  
*/
local runs = 1000
scalar lower = floor(`runs'*.025) + 1
scalar upper = floor(`runs'*.975)
disp "$S_TIME"
foreach i in clean noclean termlimits notermlimits {
matrix `i' = J(`runs', 3, .)
}
forvalues i = 1/`runs' {
quietly{
preserve
bsample, cluster(setting_unit)
	foreach j in clean noclean termlimits notermlimits {
	xi:areg voteshare incumbency i.setting if `j' == 1, a(year) cluster(setting_unit)
	scalar estimate1 = _b[incumbency]
	xi:areg voteshare incumbency i.year if `j' == 1, a(setting_unit_decade) cluster(setting_unit)
	scalar estimate2 = _b[incumbency]
	xi:ivregress 2sls voteshare (incumbency = treatment) rv* i.setting i.year if absrv < .5 & `j' == 1, cluster(setting_unit)
	scalar estimate3 = _b[incumbency]
	matrix `j'[`i',1] = estimate1 - estimate2 
	matrix `j'[`i',2] = estimate2 - estimate3
	matrix `j'[`i',3] = estimate3
	}
restore
}
if round(`i'/100) == (`i'/100) {
	disp `i'
	disp "$S_TIME"
	}
}
matrix cleandiff = clean - noclean
matrix termlimitsdiff = termlimits - notermlimits
postfile PubFinTermLimits pm pm_lower pm_upper cs cs_lower cs_upper ob ob_lower ob_upper using "Table_PubFinTermLimits.dta", replace
foreach i in clean noclean cleandiff termlimits notermlimits termlimitsdiff {
quietly {
svmat `i'
sort `i'1
sum `i'1 if _n == lower
scalar `i'_pm_lower = r(mean)
sum `i'1 if _n == upper
scalar `i'_pm_upper = r(mean)
sort `i'2
sum `i'2 if _n == lower
scalar `i'_cs_lower = r(mean)
sum `i'2 if _n == upper
scalar `i'_cs_upper = r(mean)
sort `i'3
sum `i'3 if _n == lower
scalar `i'_ob_lower = r(mean)
sum `i'3 if _n == upper
scalar `i'_ob_upper = r(mean)
post PubFinTermLimits (`i'_pm) (`i'_pm_lower) (`i'_pm_upper) (`i'_cs) (`i'_cs_lower) (`i'_cs_upper) (`i'_ob) (`i'_ob_lower) (`i'_ob_upper) 
}
}
postclose PubFinTermLimits
clear
set more off
use "Table_PubFinTermLimits.dta"
g setting = "Clean Election Laws" if _n == 1
replace setting = "No Clean Election Laws" if _n == 2
replace setting = "Difference" if _n == 3
replace setting = "Term Limits" if _n == 4
replace setting = "No Term Limits" if _n == 5
replace setting = "Difference" if _n == 6
g order = _n
order setting
foreach i of varlist pm-ob_upper {
tostring `i', replace format(%5.3f) force
replace `i' = subinstr(`i', "0.", ".", .)
replace `i' = subinstr(`i', "-.000", ".000", .)
replace `i' = trim(`i')
}
foreach i in pm cs ob {
rename `i' `i'0
g `i'1 = "[" + `i'_lower + "," + `i'_upper + "]"
}
keep setting order *0 *1
reshape long pm cs ob, i(order) j(uncertainty)
sort order uncertainty
order order uncertainty
save "Table_PubFinTermLimits_Cleaned.dta", replace
browse


********************
***** Figure 1 *****
********************
*Variation over Time
*Pooled, including South
clear
set matsize 10000
set more off
use "data.dta"
matrix B = J(46, 4, .)
forvalues i = 1912(2)2002 {
quietly{
local number = (`i' - 1910)/2
xi:areg voteshare incumbency i.setting if year >= `i' - 10 & year <= `i' + 10, a(year) cluster(setting_unit)
scalar estimate1 = _b[incumbency]
xi:areg voteshare incumbency i.year if year >= `i' - 10 & year <= `i' + 10, a(setting_unit_decade) cluster(setting_unit)
scalar estimate2 = _b[incumbency]
xi:ivregress 2sls voteshare (incumbency = treatment) rv* i.setting i.year if absrv < .5 & year >= `i' - 10 & year <= `i' + 10, cluster(setting_unit)
scalar estimate3 = _b[incumbency]
matrix B[`number', 1] = estimate1 - estimate2
matrix B[`number', 2] = estimate2 - estimate3
matrix B[`number', 3] = estimate3
matrix B[`number', 4] = `i'
}
disp `i'
}
svmat B
graph twoway line B*, yline(0)
gr_edit .legend.draw_view.setstyle, style(no)
gr_edit .style.editstyle margin(vsmall) editcopy
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
gr_edit .yaxis1.style.editstyle majorstyle(gridstyle(linestyle(color(white)))) editcopy
gr_edit .xaxis1.title.text = {}
gr_edit .xaxis1.title.text.Arrpush Year
gr_edit .xaxis1.reset_rule 1912 2002 10, tickset(major) ruletype(range) 
gr_edit .yaxis1.title.text = {}
gr_edit .yaxis1.reset_rule 0 .16 .04, tickset(major) ruletype(range)
gr_edit .plotregion1._xylines[1].style.editstyle linestyle(color(black) pattern(dash)) editcopy
gr_edit .plotregion1.plot1.style.editstyle line(color(cranberry)) editcopy
gr_edit .plotregion1.plot1.style.editstyle line(width(thick)) editcopy 
gr_edit .plotregion1.plot2.style.editstyle line(color(navy)) editcopy
gr_edit .plotregion1.plot2.style.editstyle line(width(thick)) editcopy 
gr_edit .plotregion1.plot3.style.editstyle line(color(green)) editcopy
gr_edit .plotregion1.plot3.style.editstyle line(width(thick)) editcopy 
gr_edit .xaxis1.plotregion.xscale.curmax = 2002
gr_edit .plotregion1.AddTextBox added_text editor .115 1962
gr_edit .plotregion1.added_text_new = 1
gr_edit .plotregion1.added_text_rec = 1
gr_edit .plotregion1.added_text[1].style.editstyle  angle(default) size(small) color(cranberry) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[1].text = {}
gr_edit .plotregion1.added_text[1].text.Arrpush PM
gr_edit .xaxis1.plotregion.xscale.curmax = 2004
gr_edit .plotregion1.AddTextBox added_text editor .025 1982
gr_edit .plotregion1.added_text_new = 2
gr_edit .plotregion1.added_text_rec = 2
gr_edit .plotregion1.added_text[2].style.editstyle  angle(default) size(small) color(navy) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[2].text = {}
gr_edit .plotregion1.added_text[2].text.Arrpush CS
gr_edit .plotregion1.AddTextBox added_text editor .055 1972
gr_edit .plotregion1.added_text_new = 3
gr_edit .plotregion1.added_text_rec = 3
gr_edit .plotregion1.added_text[3].style.editstyle  angle(default) size(small) color(green) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[3].text = {}
gr_edit .plotregion1.added_text[3].text.Arrpush OB
gr_edit .title.style.editstyle color(black) size(medium) editcopy
gr_edit .title.text = {}
gr_edit .title.text.Arrpush Including South
graph save "VariationOverTime_Pooled.gph", replace 
*Pooled, excluding South
clear
set matsize 10000
set more off
use "data.dta"
drop if state == "AL" | state == "AR" | state == "FL" | state == "GA" | state == "LA" | state == "MS" | state == "NC" | state == "SC" | state == "TX" | state == "TN" | state == "VA"
matrix B = J(46, 4, .)
forvalues i = 1912(2)2002 {
quietly{
local number = (`i' - 1910)/2
xi:areg voteshare incumbency i.setting if year >= `i' - 10 & year <= `i' + 10, a(year) cluster(setting_unit)
scalar estimate1 = _b[incumbency]
xi:areg voteshare incumbency i.year if year >= `i' - 10 & year <= `i' + 10, a(setting_unit_decade) cluster(setting_unit)
scalar estimate2 = _b[incumbency]
xi:ivregress 2sls voteshare (incumbency = treatment) rv* i.setting i.year if absrv < .5 & year >= `i' - 10 & year <= `i' + 10, cluster(setting_unit)
scalar estimate3 = _b[incumbency]
matrix B[`number', 1] = estimate1 - estimate2
matrix B[`number', 2] = estimate2 - estimate3
matrix B[`number', 3] = estimate3
matrix B[`number', 4] = `i'
}
disp `i'
}
svmat B
graph twoway line B*, yline(0)
gr_edit .legend.draw_view.setstyle, style(no)
gr_edit .style.editstyle margin(vsmall) editcopy
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
gr_edit .yaxis1.style.editstyle majorstyle(gridstyle(linestyle(color(white)))) editcopy
gr_edit .xaxis1.title.text = {}
gr_edit .xaxis1.title.text.Arrpush Year
gr_edit .xaxis1.reset_rule 1912 2002 10, tickset(major) ruletype(range) 
gr_edit .yaxis1.title.text = {}
gr_edit .yaxis1.reset_rule 0 .12 .04, tickset(major) ruletype(range)
gr_edit .plotregion1._xylines[1].style.editstyle linestyle(color(black) pattern(dash)) editcopy
gr_edit .plotregion1.plot1.style.editstyle line(color(cranberry)) editcopy
gr_edit .plotregion1.plot1.style.editstyle line(width(thick)) editcopy 
gr_edit .plotregion1.plot2.style.editstyle line(color(navy)) editcopy
gr_edit .plotregion1.plot2.style.editstyle line(width(thick)) editcopy 
gr_edit .plotregion1.plot3.style.editstyle line(color(green)) editcopy
gr_edit .plotregion1.plot3.style.editstyle line(width(thick)) editcopy 
gr_edit .xaxis1.plotregion.xscale.curmax = 2002
gr_edit .plotregion1.AddTextBox added_text editor .09 1962
gr_edit .plotregion1.added_text_new = 1
gr_edit .plotregion1.added_text_rec = 1
gr_edit .plotregion1.added_text[1].style.editstyle  angle(default) size(small) color(cranberry) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[1].text = {}
gr_edit .plotregion1.added_text[1].text.Arrpush PM
gr_edit .xaxis1.plotregion.xscale.curmax = 2004
gr_edit .plotregion1.AddTextBox added_text editor .022 1982
gr_edit .plotregion1.added_text_new = 2
gr_edit .plotregion1.added_text_rec = 2
gr_edit .plotregion1.added_text[2].style.editstyle  angle(default) size(small) color(navy) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[2].text = {}
gr_edit .plotregion1.added_text[2].text.Arrpush CS
gr_edit .plotregion1.AddTextBox added_text editor .052 1972
gr_edit .plotregion1.added_text_new = 3
gr_edit .plotregion1.added_text_rec = 3
gr_edit .plotregion1.added_text[3].style.editstyle  angle(default) size(small) color(green) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[3].text = {}
gr_edit .plotregion1.added_text[3].text.Arrpush OB
gr_edit .title.style.editstyle color(black) size(medium) editcopy
gr_edit .title.text = {}
gr_edit .title.text.Arrpush Excluding South
graph save "VariationOverTime_Pooled_NonSouth.gph", replace 
*Combine
graph combine "VariationOverTime_Pooled.gph" "VariationOverTime_Pooled_NonSouth.gph", col(1)
gr_edit .style.editstyle margin(zero) boxstyle(shadestyle(color(white)) linestyle(color(white))) editcopy
gr_edit .style.editstyle declared_ysize(6) editcopy
graph save "Figure1.gph", replace



********************
***** Table A1 *****
********************
*Testing the Exclusion Restriction using Governors with a One-Term Limit
clear
set more off
use "data.dta"
keep if setting == "gov"
g onetermlimit = state == "VA"
replace onetermlimit = 1 if state == "AL" & year < 1968
replace onetermlimit = 1 if state == "FL" & year < 1968
replace onetermlimit = 1 if state == "GA" & year < 1976
replace onetermlimit = 1 if state == "IN" & year < 1972
replace onetermlimit = 1 if state == "KY" & year < 1992
replace onetermlimit = 1 if state == "LA" & year < 1966
replace onetermlimit = 1 if state == "MS" & year < 1988
replace onetermlimit = 1 if state == "MO" & year < 1965
replace onetermlimit = 1 if state == "NC" & year < 1977
replace onetermlimit = 1 if state == "OK" & year < 1966
replace onetermlimit = 1 if state == "PA" & year < 1967
replace onetermlimit = 1 if state == "SC" & year < 1980
replace onetermlimit = 1 if state == "TN" & year < 1978 & year > 1954 
replace onetermlimit = 1 if state == "WV" & year < 1970
keep if onetermlimit == 1
reg voteshare treatment rv*, cluster(state) 
areg voteshare treatment rv*, cluster(state) a(state)
areg voteshare treatment rv*, cluster(state) a(year)
xi:areg voteshare treatment i.state, cluster(state) a(year)


********************
***** Table A2 *****
******************** 
*Pooled Results under Different Re-weighting Schemes
clear
set matsize 10000
set more off
set seed 60637
use "data.dta"
quietly {
xi:areg voteshare incumbency i.setting, a(year) cluster(setting_unit)
scalar estimate1 = _b[incumbency]
xi:areg voteshare incumbency i.year, a(setting_unit_decade) cluster(setting_unit)
scalar estimate2 = _b[incumbency]
xi:reg incumbency treatment rv* i.setting i.year if absrv < .5, cluster(setting_unit)
test treatment = 0
xi:ivregress 2sls voteshare (incumbency = treatment) rv* i.setting i.year if absrv < .5, cluster(setting_unit)
scalar estimate3 = _b[incumbency]
scalar pm_unweighted = estimate1 - estimate2
scalar cs_unweighted = estimate2 - estimate3
scalar ob_unweighted = estimate3
*weight by state
egen sdinc = sd(incumbency), by(state)
g weight2 = 1/(sdinc^2)
g close = absrv < .05
egen meanclose = mean(close), by(state)
g weight3 = 1/meanclose
xi:areg voteshare incumbency i.setting, a(year) cluster(setting_unit)
scalar estimate1 = _b[incumbency]
xi:areg voteshare incumbency i.year [aw = weight2], a(setting_unit_decade) cluster(setting_unit)
scalar estimate2 = _b[incumbency]
xi:ivregress 2sls voteshare (incumbency = treatment) rv* i.setting i.year if absrv < .5 [aw = weight3], cluster(setting_unit)
scalar estimate3 = _b[incumbency]
scalar pm_state = estimate1 - estimate2
scalar cs_state = estimate2 - estimate3
scalar ob_state = estimate3
*weight by year
drop sdinc weight2 close meanclose weight3
egen sdinc = sd(incumbency), by(year)
g weight2 = 1/(sdinc^2)
g close = absrv < .05
egen meanclose = mean(close), by(year)
g weight3 = 1/meanclose
xi:areg voteshare incumbency i.setting, a(year) cluster(setting_unit)
scalar estimate1 = _b[incumbency]
xi:areg voteshare incumbency i.year [aw = weight2], a(setting_unit_decade) cluster(setting_unit)
scalar estimate2 = _b[incumbency]
xi:ivregress 2sls voteshare (incumbency = treatment) rv* i.setting i.year if absrv < .5 [aw = weight3], cluster(setting_unit)
scalar estimate3 = _b[incumbency]
scalar pm_year = estimate1 - estimate2
scalar cs_year = estimate2 - estimate3
scalar ob_year = estimate3
*weight by state-decade
drop sdinc weight2 close meanclose weight3
egen state_decade = group(state decade)
egen sdinc = sd(incumbency), by(state_decade)
g weight2 = 1/(sdinc^2)
g close = absrv < .05
egen meanclose = mean(close), by(state_decade)
g weight3 = 1/meanclose
xi:areg voteshare incumbency i.setting, a(year) cluster(setting_unit)
scalar estimate1 = _b[incumbency]
xi:areg voteshare incumbency i.year [aw = weight2], a(setting_unit_decade) cluster(setting_unit)
scalar estimate2 = _b[incumbency]
xi:ivregress 2sls voteshare (incumbency = treatment) rv* i.setting i.year if absrv < .5 [aw = weight3], cluster(setting_unit)
scalar estimate3 = _b[incumbency]
scalar pm_statedecade = estimate1 - estimate2
scalar cs_statedecade = estimate2 - estimate3
scalar ob_statedecade = estimate3
drop sdinc weight2 close meanclose weight3
}
*point estimates
foreach i in unweighted state year statedecade {
foreach j in pm cs ob {
disp "`j'" "_" "`i'"
disp round(`j'_`i'*1000)/1000
}
}
*bootstrap for confidence intervals 
/*
Warning: This takes approximately 10 hours on my desktop computer. To save time, 
users can reduce the number of runs below (e.g., change "local runs = 1000" to
"local runs = "200"). This will reduce the precision with which the confidence 
intervals are estimated, and they won't perfectly match the numbers in the 
table. If you change the number, be sure to pick a multiple of 40, so that you
will have exactly 5% of the bootstrapped samples outside your confidence interavals.  
*/
local runs = 1000
scalar lower = floor(`runs'*.025) + 1
scalar upper = floor(`runs'*.975)
disp "$S_TIME"
matrix B = J(`runs', 12, .)
forvalues i = 1/`runs' {
quietly {
preserve
bsample, cluster(setting_unit)
egen sdinc_a = sd(incumbency), by(state)
g weight2a = 1/(sdinc_a^2)
egen sdinc_b = sd(incumbency), by(year)
g weight2b = 1/(sdinc_b^2)
egen sdinc_c = sd(incumbency), by(state_decade)
g weight2c = 1/(sdinc_c^2)
g close = absrv < .05
egen meanclose_a = mean(close), by(state)
g weight3a = 1/meanclose_a
egen meanclose_b = mean(close), by(year)
g weight3b = 1/meanclose_b
egen meanclose_c = mean(close), by(state_decade)
g weight3c = 1/meanclose_c
xi:areg voteshare incumbency i.setting, a(year) cluster(setting_unit)
scalar estimate1 = _b[incumbency]
xi:areg voteshare incumbency i.year, a(setting_unit_decade) cluster(setting_unit)
scalar estimate2 = _b[incumbency]
xi:areg voteshare incumbency i.year [aw = weight2a], a(setting_unit_decade) cluster(setting_unit)
scalar estimate2a = _b[incumbency]
xi:areg voteshare incumbency i.year [aw = weight2b], a(setting_unit_decade) cluster(setting_unit)
scalar estimate2b = _b[incumbency]
xi:areg voteshare incumbency i.year [aw = weight2c], a(setting_unit_decade) cluster(setting_unit)
scalar estimate2c = _b[incumbency]
xi:ivregress 2sls voteshare (incumbency = treatment) rv* i.setting i.year if absrv < .5, cluster(setting_unit)
scalar estimate3 = _b[incumbency]
xi:ivregress 2sls voteshare (incumbency = treatment) rv* i.setting i.year if absrv < .5 [aw = weight3a], cluster(setting_unit)
scalar estimate3a = _b[incumbency]
xi:ivregress 2sls voteshare (incumbency = treatment) rv* i.setting i.year if absrv < .5 [aw = weight3b], cluster(setting_unit)
scalar estimate3b = _b[incumbency]
xi:ivregress 2sls voteshare (incumbency = treatment) rv* i.setting i.year if absrv < .5 [aw = weight3c], cluster(setting_unit)
scalar estimate3c = _b[incumbency]
matrix B[`i',1] = estimate1 - estimate2
matrix B[`i',2] = estimate2 - estimate3
matrix B[`i',3] = estimate3
matrix B[`i',4] = estimate1 - estimate2a
matrix B[`i',5] = estimate2a - estimate3a
matrix B[`i',6] = estimate3a
matrix B[`i',7] = estimate1 - estimate2b
matrix B[`i',8] = estimate2b - estimate3b
matrix B[`i',9] = estimate3b
matrix B[`i',10] = estimate1 - estimate2c
matrix B[`i',11] = estimate2c - estimate3c
matrix B[`i',12] = estimate3c
restore
}
if `i'/100 == round(`i'/100) {
	disp `i'
	disp "$S_TIME"
	}
}
svmat B
sort B1
sum B1 if _n == lower
scalar pm_unweighted_lower = r(mean)
sum B1 if _n == upper
scalar pm_unweighted_upper = r(mean)
sort B2
sum B2 if _n == lower
scalar cs_unweighted_lower = r(mean)
sum B2 if _n == upper
scalar cs_unweighted_upper = r(mean)
sort B3
sum B3 if _n == lower
scalar ob_unweighted_lower = r(mean)
sum B3 if _n == upper
scalar ob_unweighted_upper = r(mean)
sort B4
sum B4 if _n == lower
scalar pm_state_lower = r(mean)
sum B4 if _n == upper
scalar pm_state_upper = r(mean)
sort B5
sum B5 if _n == lower
scalar cs_state_lower = r(mean)
sum B5 if _n == upper
scalar cs_state_upper = r(mean)
sort B6
sum B6 if _n == lower
scalar ob_state_lower = r(mean)
sum B6 if _n == upper
scalar ob_state_upper = r(mean)
sort B7
sum B7 if _n == lower
scalar pm_year_lower = r(mean)
sum B7 if _n == upper
scalar pm_year_upper = r(mean)
sort B8
sum B8 if _n == lower
scalar cs_year_lower = r(mean)
sum B8 if _n == upper
scalar cs_year_upper = r(mean)
sort B9
sum B9 if _n == lower
scalar ob_year_lower = r(mean)
sum B9 if _n == upper
scalar ob_year_upper = r(mean)
sort B10
sum B10 if _n == lower
scalar pm_statedecade_lower = r(mean)
sum B10 if _n == upper
scalar pm_statedecade_upper = r(mean)
sort B11
sum B11 if _n == lower
scalar cs_statedecade_lower = r(mean)
sum B11 if _n == upper
scalar cs_statedecade_upper = r(mean)
sort B12
sum B12 if _n == lower
scalar ob_statedecade_lower = r(mean)
sum B12 if _n == upper
scalar ob_statedecade_upper = r(mean)
postfile PooledReweighting pm pm_lower pm_upper cs cs_lower cs_upper ob ob_lower ob_upper using "Table_PooledReweighting.dta", replace
post PooledReweighting (pm_unweighted) (pm_unweighted_lower) (pm_unweighted_upper) (cs_unweighted) (cs_unweighted_lower) (cs_unweighted_upper) (ob_unweighted) (ob_unweighted_lower) (ob_unweighted_upper)
post PooledReweighting (pm_state) (pm_state_lower) (pm_state_upper) (cs_state) (cs_state_lower) (cs_state_upper) (ob_state) (ob_state_lower) (ob_state_upper)
post PooledReweighting (pm_year) (pm_year_lower) (pm_year_upper) (cs_year) (cs_year_lower) (cs_year_upper) (ob_year) (ob_year_lower) (ob_year_upper)
post PooledReweighting (pm_statedecade) (pm_statedecade_lower) (pm_statedecade_upper) (cs_statedecade) (cs_statedecade_lower) (cs_statedecade_upper) (ob_statedecade) (ob_statedecade_lower) (ob_statedecade_upper)
postclose PooledReweighting
clear
set more off
use "Table_PooledReweighting.dta"
g weightby = "unweighted" if _n == 1
replace weightby = "state" if _n == 2
replace weightby = "year" if _n == 3
replace weightby = "state-decade" if _n == 4
g order = _n
order weightby
foreach i of varlist pm-ob_upper {
tostring `i', replace format(%5.3f) force
replace `i' = subinstr(`i', "0.", ".", .)
replace `i' = subinstr(`i', "-.000", ".000", .)
replace `i' = trim(`i')
}
foreach i in pm cs ob {
rename `i' `i'0
g `i'1 = "[" + `i'_lower + "," + `i'_upper + "]"
}
keep weightby order *0 *1
reshape long pm cs ob, i(order) j(uncertainty)
sort order uncertainty
order order uncertainty
save "Table_PooledReweighting_Cleaned.dta", replace
browse


*********************
***** Figure A1 *****
*********************
*Variation over Time and across Settings
*Senate
clear
set matsize 10000
set more off
use "data.dta"
keep if setting == "senate"
matrix B = J(9, 4, .)
forvalues i = 1922(10)2002 {
quietly{
local number = (`i' - 1912)/10
xi:areg voteshare incumbency i.setting if decade == `i', a(year) cluster(setting_unit)
scalar estimate1 = _b[incumbency]
xi:areg voteshare incumbency i.year if decade == `i', a(setting_unit_decade) cluster(setting_unit)
scalar estimate2 = _b[incumbency]
xi:ivregress 2sls voteshare (incumbency = treatment) rv* i.setting i.year if absrv < .5 & decade == `i', cluster(setting_unit)
scalar estimate3 = _b[incumbency]
matrix B[`number', 1] = estimate1 - estimate2
matrix B[`number', 2] = estimate2 - estimate3
matrix B[`number', 3] = estimate3
matrix B[`number', 4] = `i'
}
disp `i'
}
svmat B
graph twoway line B*
gr_edit .legend.draw_view.setstyle, style(no)
gr_edit .style.editstyle margin(vsmall) editcopy
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
gr_edit .yaxis1.style.editstyle majorstyle(gridstyle(linestyle(color(white)))) editcopy
gr_edit .xaxis1.title.text = {}
gr_edit .xaxis1.title.text.Arrpush Decade
gr_edit .xaxis1.reset_rule 1922 2002 10, tickset(major) ruletype(range) 
gr_edit .yaxis1.title.text = {}
gr_edit .yaxis1.reset_rule 0 .15 .05, tickset(major) ruletype(range)
gr_edit .plotregion1.plot1.style.editstyle line(color(cranberry)) editcopy
gr_edit .plotregion1.plot1.style.editstyle line(width(thick)) editcopy 
gr_edit .plotregion1.plot2.style.editstyle line(color(navy)) editcopy
gr_edit .plotregion1.plot2.style.editstyle line(width(thick)) editcopy 
gr_edit .plotregion1.plot3.style.editstyle line(color(green)) editcopy
gr_edit .plotregion1.plot3.style.editstyle line(width(thick)) editcopy 
gr_edit .xaxis1.plotregion.xscale.curmax = 2002
gr_edit .plotregion1.AddTextBox added_text editor .105 1950
gr_edit .plotregion1.added_text_new = 1
gr_edit .plotregion1.added_text_rec = 1
gr_edit .plotregion1.added_text[1].style.editstyle  angle(default) size(small) color(cranberry) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[1].text = {}
gr_edit .plotregion1.added_text[1].text.Arrpush PM
gr_edit .xaxis1.plotregion.xscale.curmax = 2004
gr_edit .plotregion1.AddTextBox added_text editor .045 1980
gr_edit .plotregion1.added_text_new = 2
gr_edit .plotregion1.added_text_rec = 2
gr_edit .plotregion1.added_text[2].style.editstyle  angle(default) size(small) color(navy) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[2].text = {}
gr_edit .plotregion1.added_text[2].text.Arrpush CS
gr_edit .plotregion1.AddTextBox added_text editor .085 1980
gr_edit .plotregion1.added_text_new = 3
gr_edit .plotregion1.added_text_rec = 3
gr_edit .plotregion1.added_text[3].style.editstyle  angle(default) size(small) color(green) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[3].text = {}
gr_edit .plotregion1.added_text[3].text.Arrpush OB
gr_edit .title.style.editstyle color(black) editcopy
gr_edit .title.text = {}
gr_edit .title.text.Arrpush U.S. Senate
graph save "VariationOverTime_Senate.gph", replace 
*U.S. House
clear
set matsize 10000
set more off
use "data.dta"
keep if setting == "house"
matrix B = J(11, 4, .)
forvalues i = 1902(10)2002 {
quietly{
local number = (`i' - 1892)/10
xi:areg voteshare incumbency i.setting if decade == `i', a(year) cluster(setting_unit)
scalar estimate1 = _b[incumbency]
xi:areg voteshare incumbency i.year if decade == `i', a(setting_unit_decade) cluster(setting_unit)
scalar estimate2 = _b[incumbency]
xi:ivregress 2sls voteshare (incumbency = treatment) rv* i.setting i.year if absrv < .5 & decade == `i', cluster(setting_unit)
scalar estimate3 = _b[incumbency]
matrix B[`number', 1] = estimate1 - estimate2
matrix B[`number', 2] = estimate2 - estimate3
matrix B[`number', 3] = estimate3
matrix B[`number', 4] = `i'
}
disp `i'
}
svmat B
graph twoway line B*
gr_edit .legend.draw_view.setstyle, style(no)
gr_edit .style.editstyle margin(vsmall) editcopy
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
gr_edit .yaxis1.style.editstyle majorstyle(gridstyle(linestyle(color(white)))) editcopy
gr_edit .xaxis1.title.text = {}
gr_edit .xaxis1.title.text.Arrpush Decade
gr_edit .xaxis1.reset_rule 1902 2002 10, tickset(major) ruletype(range) 
gr_edit .yaxis1.title.text = {}
gr_edit .yaxis1.reset_rule 0 .15 .05, tickset(major) ruletype(range)
gr_edit .plotregion1.plot1.style.editstyle line(color(cranberry)) editcopy
gr_edit .plotregion1.plot1.style.editstyle line(width(thick)) editcopy 
gr_edit .plotregion1.plot2.style.editstyle line(color(navy)) editcopy
gr_edit .plotregion1.plot2.style.editstyle line(width(thick)) editcopy 
gr_edit .plotregion1.plot3.style.editstyle line(color(green)) editcopy
gr_edit .plotregion1.plot3.style.editstyle line(width(thick)) editcopy 
gr_edit .xaxis1.plotregion.xscale.curmax = 2002
gr_edit .plotregion1.AddTextBox added_text editor .11 1990
gr_edit .plotregion1.added_text_new = 1
gr_edit .plotregion1.added_text_rec = 1
gr_edit .plotregion1.added_text[1].style.editstyle  angle(default) size(small) color(cranberry) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[1].text = {}
gr_edit .plotregion1.added_text[1].text.Arrpush PM
gr_edit .xaxis1.plotregion.xscale.curmax = 2004
gr_edit .plotregion1.AddTextBox added_text editor .025 1986
gr_edit .plotregion1.added_text_new = 2
gr_edit .plotregion1.added_text_rec = 2
gr_edit .plotregion1.added_text[2].style.editstyle  angle(default) size(small) color(navy) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[2].text = {}
gr_edit .plotregion1.added_text[2].text.Arrpush CS
gr_edit .plotregion1.AddTextBox added_text editor .065 1986
gr_edit .plotregion1.added_text_new = 3
gr_edit .plotregion1.added_text_rec = 3
gr_edit .plotregion1.added_text[3].style.editstyle  angle(default) size(small) color(green) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[3].text = {}
gr_edit .plotregion1.added_text[3].text.Arrpush OB
gr_edit .title.style.editstyle color(black) editcopy
gr_edit .title.text = {}
gr_edit .title.text.Arrpush U.S. House
graph save "VariationOverTime_House.gph", replace 
drop B*
drop if state == "AL" | state == "AR" | state == "FL" | state == "GA" | state == "LA" | state == "MS" | state == "NC" | state == "SC" | state == "TX" | state == "TN" | state == "VA"
matrix B = J(11, 4, .)
forvalues i = 1902(10)2002 {
quietly{
local number = (`i' - 1892)/10
xi:areg voteshare incumbency i.setting if decade == `i', a(year) cluster(setting_unit)
scalar estimate1 = _b[incumbency]
xi:areg voteshare incumbency i.year if decade == `i', a(setting_unit_decade) cluster(setting_unit)
scalar estimate2 = _b[incumbency]
xi:ivregress 2sls voteshare (incumbency = treatment) rv* i.setting i.year if absrv < .5 & decade == `i', cluster(setting_unit)
scalar estimate3 = _b[incumbency]
matrix B[`number', 1] = estimate1 - estimate2
matrix B[`number', 2] = estimate2 - estimate3
matrix B[`number', 3] = estimate3
matrix B[`number', 4] = `i'
}
disp `i'
}
svmat B
graph twoway line B*
gr_edit .legend.draw_view.setstyle, style(no)
gr_edit .style.editstyle margin(vsmall) editcopy
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
gr_edit .yaxis1.style.editstyle majorstyle(gridstyle(linestyle(color(white)))) editcopy
gr_edit .xaxis1.title.text = {}
gr_edit .xaxis1.title.text.Arrpush Decade
gr_edit .xaxis1.reset_rule 1902 2002 10, tickset(major) ruletype(range) 
gr_edit .yaxis1.title.text = {}
gr_edit .yaxis1.reset_rule 0 .15 .05, tickset(major) ruletype(range)
gr_edit .plotregion1.plot1.style.editstyle line(color(cranberry)) editcopy
gr_edit .plotregion1.plot1.style.editstyle line(width(thick)) editcopy 
gr_edit .plotregion1.plot2.style.editstyle line(color(navy)) editcopy
gr_edit .plotregion1.plot2.style.editstyle line(width(thick)) editcopy 
gr_edit .plotregion1.plot3.style.editstyle line(color(green)) editcopy
gr_edit .plotregion1.plot3.style.editstyle line(width(thick)) editcopy 
gr_edit .xaxis1.plotregion.xscale.curmax = 2002
gr_edit .plotregion1.AddTextBox added_text editor .11 1990
gr_edit .plotregion1.added_text_new = 1
gr_edit .plotregion1.added_text_rec = 1
gr_edit .plotregion1.added_text[1].style.editstyle  angle(default) size(small) color(cranberry) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[1].text = {}
gr_edit .plotregion1.added_text[1].text.Arrpush PM
gr_edit .xaxis1.plotregion.xscale.curmax = 2004
gr_edit .plotregion1.AddTextBox added_text editor .015 1986
gr_edit .plotregion1.added_text_new = 2
gr_edit .plotregion1.added_text_rec = 2
gr_edit .plotregion1.added_text[2].style.editstyle  angle(default) size(small) color(navy) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[2].text = {}
gr_edit .plotregion1.added_text[2].text.Arrpush CS
gr_edit .plotregion1.AddTextBox added_text editor .07 1986
gr_edit .plotregion1.added_text_new = 3
gr_edit .plotregion1.added_text_rec = 3
gr_edit .plotregion1.added_text[3].style.editstyle  angle(default) size(small) color(green) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[3].text = {}
gr_edit .plotregion1.added_text[3].text.Arrpush OB
gr_edit .title.style.editstyle color(black) editcopy
gr_edit .title.text = {}
gr_edit .title.text.Arrpush U.S. House (Non-South)
graph save "VariationOverTime_House_NonSouth.gph", replace 
*Governors
clear
set matsize 10000
set more off
use "data.dta"
keep if setting == "gov"
matrix B = J(6, 4, .)
forvalues i = 1952(10)2002 {
quietly{
local number = (`i' - 1942)/10
xi:areg voteshare incumbency i.setting if decade == `i', a(year) cluster(setting_unit)
scalar estimate1 = _b[incumbency]
xi:areg voteshare incumbency i.year if decade == `i', a(setting_unit_decade) cluster(setting_unit)
scalar estimate2 = _b[incumbency]
xi:ivregress 2sls voteshare (incumbency = treatment) rv* i.setting i.year if absrv < .5 & decade == `i', cluster(setting_unit)
scalar estimate3 = _b[incumbency]
matrix B[`number', 1] = estimate1 - estimate2
matrix B[`number', 2] = estimate2 - estimate3
matrix B[`number', 3] = estimate3
matrix B[`number', 4] = `i'
}
disp `i'
}
svmat B
graph twoway line B*
gr_edit .legend.draw_view.setstyle, style(no)
gr_edit .style.editstyle margin(vsmall) editcopy
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
gr_edit .yaxis1.style.editstyle majorstyle(gridstyle(linestyle(color(white)))) editcopy
gr_edit .xaxis1.title.text = {}
gr_edit .xaxis1.title.text.Arrpush Decade
gr_edit .xaxis1.reset_rule 1952 2002 10, tickset(major) ruletype(range) 
gr_edit .yaxis1.title.text = {}
gr_edit .yaxis1.reset_rule 0 .15 .05, tickset(major) ruletype(range)
gr_edit .plotregion1.plot1.style.editstyle line(color(cranberry)) editcopy
gr_edit .plotregion1.plot1.style.editstyle line(width(thick)) editcopy 
gr_edit .plotregion1.plot2.style.editstyle line(color(navy)) editcopy
gr_edit .plotregion1.plot2.style.editstyle line(width(thick)) editcopy 
gr_edit .plotregion1.plot3.style.editstyle line(color(green)) editcopy
gr_edit .plotregion1.plot3.style.editstyle line(width(thick)) editcopy 
gr_edit .xaxis1.plotregion.xscale.curmax = 2004
gr_edit .plotregion1.AddTextBox added_text editor .04 1990
gr_edit .plotregion1.added_text_new = 1
gr_edit .plotregion1.added_text_rec = 1
gr_edit .plotregion1.added_text[1].style.editstyle  angle(default) size(small) color(cranberry) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[1].text = {}
gr_edit .plotregion1.added_text[1].text.Arrpush PM
gr_edit .xaxis1.plotregion.xscale.curmax = 2004
gr_edit .plotregion1.AddTextBox added_text editor -.01 1985
gr_edit .plotregion1.added_text_new = 2
gr_edit .plotregion1.added_text_rec = 2
gr_edit .plotregion1.added_text[2].style.editstyle  angle(default) size(small) color(navy) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[2].text = {}
gr_edit .plotregion1.added_text[2].text.Arrpush CS
gr_edit .plotregion1.AddTextBox added_text editor .09 1982
gr_edit .plotregion1.added_text_new = 3
gr_edit .plotregion1.added_text_rec = 3
gr_edit .plotregion1.added_text[3].style.editstyle  angle(default) size(small) color(green) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[3].text = {}
gr_edit .plotregion1.added_text[3].text.Arrpush OB
gr_edit .title.style.editstyle color(black) editcopy
gr_edit .title.text = {}
gr_edit .title.text.Arrpush Governors
graph save "VariationOverTime_Governors.gph", replace 
*Statewide High
clear
set matsize 10000
set more off
use "data.dta"
keep if setting == "secstate" | setting == "ltgov" | setting == "attygenl"
matrix B = J(6, 4, .)
forvalues i = 1952(10)2002 {
quietly{
local number = (`i' - 1942)/10
xi:areg voteshare incumbency i.setting if decade == `i', a(year) cluster(setting_unit)
scalar estimate1 = _b[incumbency]
xi:areg voteshare incumbency i.year if decade == `i', a(setting_unit_decade) cluster(setting_unit)
scalar estimate2 = _b[incumbency]
xi:ivregress 2sls voteshare (incumbency = treatment) rv* i.setting i.year if absrv < .5 & decade == `i', cluster(setting_unit)
scalar estimate3 = _b[incumbency]
matrix B[`number', 1] = estimate1 - estimate2
matrix B[`number', 2] = estimate2 - estimate3
matrix B[`number', 3] = estimate3
matrix B[`number', 4] = `i'
}
disp `i'
}
svmat B
graph twoway line B*
gr_edit .legend.draw_view.setstyle, style(no)
gr_edit .style.editstyle margin(vsmall) editcopy
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
gr_edit .yaxis1.style.editstyle majorstyle(gridstyle(linestyle(color(white)))) editcopy
gr_edit .xaxis1.title.text = {}
gr_edit .xaxis1.title.text.Arrpush Decade
gr_edit .xaxis1.reset_rule 1952 2002 10, tickset(major) ruletype(range) 
gr_edit .yaxis1.title.text = {}
gr_edit .yaxis1.reset_rule 0 .15 .05, tickset(major) ruletype(range)
gr_edit .plotregion1.plot1.style.editstyle line(color(cranberry)) editcopy
gr_edit .plotregion1.plot1.style.editstyle line(width(thick)) editcopy 
gr_edit .plotregion1.plot2.style.editstyle line(color(navy)) editcopy
gr_edit .plotregion1.plot2.style.editstyle line(width(thick)) editcopy 
gr_edit .plotregion1.plot3.style.editstyle line(color(green)) editcopy
gr_edit .plotregion1.plot3.style.editstyle line(width(thick)) editcopy 
gr_edit .xaxis1.plotregion.xscale.curmax = 2004
gr_edit .plotregion1.AddTextBox added_text editor .095 1962
gr_edit .plotregion1.added_text_new = 1
gr_edit .plotregion1.added_text_rec = 1
gr_edit .plotregion1.added_text[1].style.editstyle  angle(default) size(small) color(cranberry) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[1].text = {}
gr_edit .plotregion1.added_text[1].text.Arrpush PM
gr_edit .xaxis1.plotregion.xscale.curmax = 2004
gr_edit .plotregion1.AddTextBox added_text editor .005 1991
gr_edit .plotregion1.added_text_new = 2
gr_edit .plotregion1.added_text_rec = 2
gr_edit .plotregion1.added_text[2].style.editstyle  angle(default) size(small) color(navy) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[2].text = {}
gr_edit .plotregion1.added_text[2].text.Arrpush CS
gr_edit .plotregion1.AddTextBox added_text editor .08 1992
gr_edit .plotregion1.added_text_new = 3
gr_edit .plotregion1.added_text_rec = 3
gr_edit .plotregion1.added_text[3].style.editstyle  angle(default) size(small) color(green) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[3].text = {}
gr_edit .plotregion1.added_text[3].text.Arrpush OB
gr_edit .title.style.editstyle color(black) editcopy
gr_edit .title.text = {}
gr_edit .title.text.Arrpush Statewide (High Salience)
graph save "VariationOverTime_Statewide_High.gph", replace 
*Statewide Low
clear
set matsize 10000
set more off
use "data.dta"
keep if setting == "agric" | setting == "auditor" | setting == "clerk" | setting == "comptroll" | setting == "education" | setting == "finance" | setting == "inspector" ///
| setting == "insurance" | setting == "labor" | setting == "lands" | setting == "mines" | setting == "printer" | setting == "reporter" | setting == "surveyor" | setting == "treasurer"
matrix B = J(6, 4, .)
forvalues i = 1952(10)2002 {
quietly{
local number = (`i' - 1942)/10
xi:areg voteshare incumbency i.setting if decade == `i', a(year) cluster(setting_unit)
scalar estimate1 = _b[incumbency]
xi:areg voteshare incumbency i.year if decade == `i', a(setting_unit_decade) cluster(setting_unit)
scalar estimate2 = _b[incumbency]
xi:ivregress 2sls voteshare (incumbency = treatment) rv* i.setting i.year if absrv < .5 & decade == `i', cluster(setting_unit)
scalar estimate3 = _b[incumbency]
matrix B[`number', 1] = estimate1 - estimate2
matrix B[`number', 2] = estimate2 - estimate3
matrix B[`number', 3] = estimate3
matrix B[`number', 4] = `i'
}
disp `i'
}
svmat B
graph twoway line B*
gr_edit .legend.draw_view.setstyle, style(no)
gr_edit .style.editstyle margin(vsmall) editcopy
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
gr_edit .yaxis1.style.editstyle majorstyle(gridstyle(linestyle(color(white)))) editcopy
gr_edit .xaxis1.title.text = {}
gr_edit .xaxis1.title.text.Arrpush Decade
gr_edit .xaxis1.reset_rule 1952 2002 10, tickset(major) ruletype(range) 
gr_edit .yaxis1.title.text = {}
gr_edit .yaxis1.reset_rule 0 .15 .05, tickset(major) ruletype(range)
gr_edit .plotregion1.plot1.style.editstyle line(color(cranberry)) editcopy
gr_edit .plotregion1.plot1.style.editstyle line(width(thick)) editcopy 
gr_edit .plotregion1.plot2.style.editstyle line(color(navy)) editcopy
gr_edit .plotregion1.plot2.style.editstyle line(width(thick)) editcopy 
gr_edit .plotregion1.plot3.style.editstyle line(color(green)) editcopy
gr_edit .plotregion1.plot3.style.editstyle line(width(thick)) editcopy 
gr_edit .xaxis1.plotregion.xscale.curmax = 2004
gr_edit .plotregion1.AddTextBox added_text editor .085 1991
gr_edit .plotregion1.added_text_new = 1
gr_edit .plotregion1.added_text_rec = 1
gr_edit .plotregion1.added_text[1].style.editstyle  angle(default) size(small) color(cranberry) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[1].text = {}
gr_edit .plotregion1.added_text[1].text.Arrpush PM
gr_edit .xaxis1.plotregion.xscale.curmax = 2004
gr_edit .plotregion1.AddTextBox added_text editor .03 1984
gr_edit .plotregion1.added_text_new = 2
gr_edit .plotregion1.added_text_rec = 2
gr_edit .plotregion1.added_text[2].style.editstyle  angle(default) size(small) color(navy) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[2].text = {}
gr_edit .plotregion1.added_text[2].text.Arrpush CS
gr_edit .plotregion1.AddTextBox added_text editor .03 1960
gr_edit .plotregion1.added_text_new = 3
gr_edit .plotregion1.added_text_rec = 3
gr_edit .plotregion1.added_text[3].style.editstyle  angle(default) size(small) color(green) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[3].text = {}
gr_edit .plotregion1.added_text[3].text.Arrpush OB
gr_edit .title.style.editstyle color(black) editcopy
gr_edit .title.text = {}
gr_edit .title.text.Arrpush Statewide (Low Salience)
graph save "VariationOverTime_Statewide_Low.gph", replace 
*State Legislatures
clear
set matsize 10000
set more off
use "data.dta"
keep if setting == "stleg"
matrix B = J(4, 4, .)
forvalues i = 1972(10)2002 {
quietly{
local number = (`i' - 1962)/10
xi:areg voteshare incumbency i.setting if decade == `i', a(year) cluster(setting_unit)
scalar estimate1 = _b[incumbency]
xi:areg voteshare incumbency i.year if decade == `i', a(setting_unit_decade) cluster(setting_unit)
scalar estimate2 = _b[incumbency]
xi:ivregress 2sls voteshare (incumbency = treatment) rv* i.setting i.year if absrv < .5 & decade == `i', cluster(setting_unit)
scalar estimate3 = _b[incumbency]
matrix B[`number', 1] = estimate1 - estimate2
matrix B[`number', 2] = estimate2 - estimate3
matrix B[`number', 3] = estimate3
matrix B[`number', 4] = `i'
}
disp `i'
}
svmat B
graph twoway line B*
gr_edit .legend.draw_view.setstyle, style(no)
gr_edit .style.editstyle margin(vsmall) editcopy
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
gr_edit .yaxis1.style.editstyle majorstyle(gridstyle(linestyle(color(white)))) editcopy
gr_edit .xaxis1.title.text = {}
gr_edit .xaxis1.title.text.Arrpush Decade
gr_edit .xaxis1.reset_rule 1972 2002 10, tickset(major) ruletype(range) 
gr_edit .yaxis1.title.text = {}
gr_edit .yaxis1.reset_rule 0 .15 .05, tickset(major) ruletype(range)
gr_edit .plotregion1.plot1.style.editstyle line(color(cranberry)) editcopy
gr_edit .plotregion1.plot1.style.editstyle line(width(thick)) editcopy 
gr_edit .plotregion1.plot2.style.editstyle line(color(navy)) editcopy
gr_edit .plotregion1.plot2.style.editstyle line(width(thick)) editcopy 
gr_edit .plotregion1.plot3.style.editstyle line(color(green)) editcopy
gr_edit .plotregion1.plot3.style.editstyle line(width(thick)) editcopy 
gr_edit .xaxis1.plotregion.xscale.curmax = 2004
gr_edit .plotregion1.AddTextBox added_text editor .115 1987
gr_edit .plotregion1.added_text_new = 1
gr_edit .plotregion1.added_text_rec = 1
gr_edit .plotregion1.added_text[1].style.editstyle  angle(default) size(small) color(cranberry) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[1].text = {}
gr_edit .plotregion1.added_text[1].text.Arrpush PM
gr_edit .xaxis1.plotregion.xscale.curmax = 2004
gr_edit .plotregion1.AddTextBox added_text editor .02 1987
gr_edit .plotregion1.added_text_new = 2
gr_edit .plotregion1.added_text_rec = 2
gr_edit .plotregion1.added_text[2].style.editstyle  angle(default) size(small) color(navy) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[2].text = {}
gr_edit .plotregion1.added_text[2].text.Arrpush CS
gr_edit .plotregion1.AddTextBox added_text editor .055 1987
gr_edit .plotregion1.added_text_new = 3
gr_edit .plotregion1.added_text_rec = 3
gr_edit .plotregion1.added_text[3].style.editstyle  angle(default) size(small) color(green) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[3].text = {}
gr_edit .plotregion1.added_text[3].text.Arrpush OB
gr_edit .title.style.editstyle color(black) editcopy
gr_edit .title.text = {}
gr_edit .title.text.Arrpush State Legislatures
graph save "VariationOverTime_StateLegislatures.gph", replace
*Mayors
clear
set matsize 10000
set more off
use "data.dta"
keep if setting == "mayors"
matrix B = J(5, 4, .)
forvalues i = 1962(10)2002 {
quietly{
local number = (`i' - 1952)/10
xi:areg voteshare incumbency i.setting if decade == `i', a(year) cluster(setting_unit)
scalar estimate1 = _b[incumbency]
xi:areg voteshare incumbency i.year if decade == `i', a(setting_unit_decade) cluster(setting_unit)
scalar estimate2 = _b[incumbency]
xi:ivregress 2sls voteshare (incumbency = treatment) rv* i.setting i.year if absrv < .5 & decade == `i', cluster(setting_unit)
scalar estimate3 = _b[incumbency]
matrix B[`number', 1] = estimate1 - estimate2
matrix B[`number', 2] = estimate2 - estimate3
matrix B[`number', 3] = estimate3
matrix B[`number', 4] = `i'
}
disp `i'
}
svmat B
graph twoway line B*
gr_edit .legend.draw_view.setstyle, style(no)
gr_edit .style.editstyle margin(vsmall) editcopy
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
gr_edit .yaxis1.style.editstyle majorstyle(gridstyle(linestyle(color(white)))) editcopy
gr_edit .xaxis1.title.text = {}
gr_edit .xaxis1.title.text.Arrpush Decade
gr_edit .xaxis1.reset_rule 1962 2002 10, tickset(major) ruletype(range) 
gr_edit .yaxis1.title.text = {}
gr_edit .yaxis1.reset_rule 0 .15 .05, tickset(major) ruletype(range)
gr_edit .plotregion1.plot1.style.editstyle line(color(cranberry)) editcopy
gr_edit .plotregion1.plot1.style.editstyle line(width(thick)) editcopy 
gr_edit .plotregion1.plot2.style.editstyle line(color(navy)) editcopy
gr_edit .plotregion1.plot2.style.editstyle line(width(thick)) editcopy 
gr_edit .plotregion1.plot3.style.editstyle line(color(green)) editcopy
gr_edit .plotregion1.plot3.style.editstyle line(width(thick)) editcopy 
gr_edit .xaxis1.plotregion.xscale.curmax = 2004
gr_edit .plotregion1.AddTextBox added_text editor .13 1985
gr_edit .plotregion1.added_text_new = 1
gr_edit .plotregion1.added_text_rec = 1
gr_edit .plotregion1.added_text[1].style.editstyle  angle(default) size(small) color(cranberry) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[1].text = {}
gr_edit .plotregion1.added_text[1].text.Arrpush PM
gr_edit .xaxis1.plotregion.xscale.curmax = 2004
gr_edit .plotregion1.AddTextBox added_text editor .01 1989
gr_edit .plotregion1.added_text_new = 2
gr_edit .plotregion1.added_text_rec = 2
gr_edit .plotregion1.added_text[2].style.editstyle  angle(default) size(small) color(navy) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[2].text = {}
gr_edit .plotregion1.added_text[2].text.Arrpush CS
gr_edit .plotregion1.AddTextBox added_text editor .08 1985
gr_edit .plotregion1.added_text_new = 3
gr_edit .plotregion1.added_text_rec = 3
gr_edit .plotregion1.added_text[3].style.editstyle  angle(default) size(small) color(green) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[3].text = {}
gr_edit .plotregion1.added_text[3].text.Arrpush OB
gr_edit .title.style.editstyle color(black) editcopy
gr_edit .title.text = {}
gr_edit .title.text.Arrpush Mayors
graph save "VariationOverTime_Mayors.gph", replace 
clear
graph combine "VariationOverTime_Senate.gph" "VariationOverTime_House.gph" "VariationOverTime_House_NonSouth.gph" ///
"VariationOverTime_Governors.gph" "VariationOverTime_Statewide_High.gph" "VariationOverTime_Statewide_Low.gph" ///
 "VariationOverTime_StateLegislatures.gph" "VariationOverTime_Mayors.gph", cols(2)
gr_edit .style.editstyle declared_ysize(6) editcopy
gr_edit .style.editstyle margin(zero) editcopy
gr_edit .style.editstyle boxstyle(shadestyle(color(white))) editcopy
gr_edit .style.editstyle boxstyle(linestyle(color(white))) editcopy
forvalues i = 1/8 {
*gr_edit .plotregion1.graph`i'.yaxis1.reset_rule 0 .15 .05, tickset(major) ruletype(range) 
gr_edit .plotregion1.graph`i'.title.style.editstyle size(medlarge) editcopy
gr_edit .plotregion1.graph`i'.yaxis1.style.editstyle majorstyle(tickstyle(textstyle(size(small)))) editcopy
gr_edit .plotregion1.graph`i'.xaxis1.style.editstyle majorstyle(tickstyle(textstyle(size(small)))) editcopy
gr_edit .plotregion1.graph`i'.xaxis1.title.style.editstyle size(small) editcopy
}
forvalues i = 2/3 {
gr_edit .plotregion1.graph`i'.xaxis1.reset_rule 1902 2002 20, tickset(major) ruletype(range) 
gr_edit .plotregion1.graph`i'.xaxis1.plotregion.xscale.curmax = 2004
}
gr_edit .plotregion1.graph1.plotregion1.added_text[1].DragBy .0111018576146951 -.6802091995359834
gr_edit .plotregion1.graph1.plotregion1.added_text[3].DragBy .0142738169331792 0
gr_edit .plotregion1.graph1.plotregion1.added_text[2].DragBy -.0491653694365058 9.522928793503752
gr_edit .plotregion1.graph4.plotregion1.added_text[2].DragBy 0 5.032442045347527
gr_edit .plotregion1.graph4.plotregion1.added_text[1].DragBy .0169366013164086 .5751362337539617
gr_edit .plotregion1.graph4.plotregion1.added_text[3].DragBy .0431113488054034 8.195691330994475
gr_edit .plotregion1.graph3.plotregion1.added_text[1].DragBy -.0105123214758345 -45.97218760766356
gr_edit .plotregion1.graph3.plotregion1.added_text[3].DragBy .0052561607379172 7.89706290193002
gr_edit .plotregion1.graph3.plotregion1.added_text[2].DragBy -.006344838918816 -7.615024941146714
gr_edit .plotregion1.graph2.plotregion1.added_text[1].DragBy .0664974737428635 -44.56199780374751
gr_edit .plotregion1.graph2.plotregion1.added_text[3].DragBy -.0064875584139378 -37.51104878416721
gr_edit .plotregion1.graph2.plotregion1.added_text[2].DragBy -.0145347208363052 -6.486873098013962
gr_edit .plotregion1.graph5.plotregion1.added_text[1].DragBy .0126243033293305 -.287568116876996
gr_edit .plotregion1.graph5.plotregion1.added_text[3].DragBy .028054007398512 -3.738385519400993
gr_edit .plotregion1.graph5.plotregion1.added_text[2].DragBy -.0014027003699257 2.87568116877002
gr_edit .plotregion1.graph6.plotregion1.added_text[1].DragBy .0321308548246198 -14.95354207760405
gr_edit .plotregion1.graph6.plotregion1.added_text[2].DragBy -.0141375761228324 12.07786090883403
gr_edit .plotregion1.graph6.plotregion1.added_text[3].DragBy .0128523419298479 -1.294056525946494
gr_edit .plotregion1.graph7.plotregion1.added_text[1].DragBy .0074314705746499 .3539299900024612
gr_edit .plotregion1.graph7.plotregion1.added_text[3].DragBy .0123857842910832 .1769649950012283
gr_edit .plotregion1.graph7.plotregion1.added_text[2].DragBy -.0198172548657332 .530894985003694
gr_edit .plotregion1.graph8.plotregion1.added_text[1].DragBy .0147897539994647 -.3483998339086711
gr_edit .plotregion1.graph8.plotregion1.added_text[3].DragBy .0040335692725813 1.625865891573815
gr_edit .plotregion1.graph8.plotregion1.added_text[2].DragBy -.0107561847268834 1.045199501726051
graph save "FigureA1.gph", replace
 

